/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "Console.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomConsole.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/PrivateGdomConsole.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateIntGdomConsole.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::Console* obj)
{
    return WebCore::cacheDOMObject<WebCore::Console, GDOMConsole>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMConsole::GDOMConsole(PassRefPtr<WebCore::Console> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMConsole::~GDOMConsole()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}


/* XXX TODO: custom function gdom_console_debug */


/* XXX TODO: custom function gdom_console_error */


/* XXX TODO: custom function gdom_console_info */


/* XXX TODO: custom function gdom_console_log */


/* XXX TODO: custom function gdom_console_warn */


/* XXX TODO: custom function gdom_console_dir */


/* XXX TODO: custom function gdom_console_dirxml */


/* XXX TODO: custom function gdom_console_assert */


/* XXX TODO: custom function gdom_console_count */


/* XXX TODO: custom function gdom_console_profile */


/* XXX TODO: custom function gdom_console_profile_end */

void
gdom_console_time (GdomConsole *thiz, gchar * title)
{
    g_return_if_fail (thiz);
    WebCore::Console * item = (gdom_console_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (title);
    WebCore::String _g_title = WebCore::String::fromUTF8(title);
    item->time(_g_title);

}


/* XXX TODO: custom function gdom_console_time_end */


/* XXX TODO: custom function gdom_console_group */

void
gdom_console_group_end (GdomConsole *thiz)
{
    g_return_if_fail (thiz);
    WebCore::Console * item = (gdom_console_get_private(thiz));
    g_return_if_fail (item);
    item->groupEnd();

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "Console.h"
#include <gdom/GdomConsole.h>
#include <gdom/PrivateGdomConsole.h>
#include <gdom/PrivateIntGdomConsole.h>
#include <gdom/GdomConsoleprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomConsole, gdom_console, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomConsolePrivate {
    class WebCore::Console *item;
};

#define GDOM_CONSOLE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_CONSOLE, GdomConsolePrivate))
*/
G_END_DECLS
WebCore::Console *
gdom_console_get_private(GdomConsole *request)
{
    GDOMConsole *res;
    res = static_cast<GDOMConsole*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::Console*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
};


static void gdom_console_finalize(GObject* object)
{
    /*GdomConsole* request = GDOM_CONSOLE(object);*/
    /*GdomConsolePrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_console_parent_class)->finalize(object);
}

static void gdom_console__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomConsole *self = GDOM_CONSOLE(object);
    WebCore::Console * gself = (gdom_console_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_console__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomConsole *self = GDOM_CONSOLE(object);
    WebCore::Console * gself = (gdom_console_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_console_class_init(GdomConsoleClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_console_finalize;
    g_klass->set_property = gdom_console__set_property_fn;
    g_klass->get_property = gdom_console__get_property_fn;





    /*g_type_class_remove_private(requestClass, sizeof(GdomConsolePrivate));*/
}

static void gdom_console_init(GdomConsole* request)
{
    /*GdomConsolePrivate* priv = GDOM_CONSOLE_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

